==> flutter_mentions-0.1.0.tar.gz: lib/src/annotation_editing_controller.dart <==
part of flutter_mentions;

/// A custom implementation of [TextEditingController] to support @ mention or other
/// trigger based mentions.
class AnnotationEditingController extends TextEditingController {
  final Map<String, Annotation> _mapping;
  final String _pattern;

  // Generate the Regex pattern for matching all the suggestions in one.
  AnnotationEditingController(this._mapping)
      : _pattern = "(${_mapping.keys.map((key) => key).join('|')})";

  /// Can be used to get the markup from the controller directly.
  get markupText {
    final someVal = text.splitMapJoin(
      RegExp("$_pattern"),
      onMatch: (Match match) {
        final mention = _mapping[match[0]] != null
            ? _mapping[match[0]]
            : _mapping[_mapping.keys.firstWhere((element) {
                final reg = new RegExp(element);

                return reg.hasMatch(match[0]);
              })];

        // Default markup format for mentions
        if (!mention.disableMarkup)
          return "${mention.trigger}[__${mention.id}__](__${mention.display}__)";
        else
          return match[0];
      },
      onNonMatch: (String text) {
        return text;
      },
    );

    return someVal;
  }

  @override
  TextSpan buildTextSpan({TextStyle style, bool withComposing}) {
    List<InlineSpan> children = [];

    text.splitMapJoin(
      RegExp("$_pattern"),
      onMatch: (Match match) {
        final mention = _mapping[match[0]] != null
            ? _mapping[match[0]]
            : _mapping[_mapping.keys.firstWhere((element) {
                final reg = new RegExp(element);

                return reg.hasMatch(match[0]);
              })];

        children.add(
          TextSpan(
            text: match[0],
            style: style.merge(mention.style),
          ),
        );
        return "";
      },
      onNonMatch: (String text) {
        children.add(TextSpan(text: text, style: style));
        return "";
      },
    );
    return TextSpan(style: style, children: children);
  }
}

==> flutter_mentions-0.1.1.tar.gz: lib/src/annotation_editing_controller.dart <==
part of flutter_mentions;

/// A custom implementation of [TextEditingController] to support @ mention or other
/// trigger based mentions.
class AnnotationEditingController extends TextEditingController {
  final Map<String, Annotation> _mapping;
  final String _pattern;

  // Generate the Regex pattern for matching all the suggestions in one.
  AnnotationEditingController(this._mapping)
      : _pattern = "(${_mapping.keys.map((key) => key).join('|')})";

  /// Can be used to get the markup from the controller directly.
  String get markupText {
    final someVal = text.splitMapJoin(
      RegExp('$_pattern'),
      onMatch: (Match match) {
        final mention = _mapping[match[0]] ??
            _mapping[_mapping.keys.firstWhere((element) {
              final reg = RegExp(element);

              return reg.hasMatch(match[0]);
            })];

        // Default markup format for mentions
        if (!mention.disableMarkup) {
          return '${mention.trigger}[__${mention.id}__](__${mention.display}__)';
        } else {
          return match[0];
        }
      },
      onNonMatch: (String text) {
        return text;
      },
    );

    return someVal;
  }

  @override
  TextSpan buildTextSpan({TextStyle style, bool withComposing}) {
    var children = <InlineSpan>[];

    text.splitMapJoin(
      RegExp('$_pattern'),
      onMatch: (Match match) {
        final mention = _mapping[match[0]] ??
            _mapping[_mapping.keys.firstWhere((element) {
              final reg = RegExp(element);

              return reg.hasMatch(match[0]);
            })];

        children.add(
          TextSpan(
            text: match[0],
            style: style.merge(mention.style),
          ),
        );
        return '';
      },
      onNonMatch: (String text) {
        children.add(TextSpan(text: text, style: style));
        return '';
      },
    );
    return TextSpan(style: style, children: children);
  }
}
